@@ -39,7 +39,8 @@ def main() :
     #
     description =  "Policy utility script for SAP Data Intelligence.\nPre-requiste: vctl."
     parser = argparse.ArgumentParser(description=description)
-    parser.add_argument('config', help = 'Specifies yaml-config file')
+    parser.add_argument('-c',
+                        '--config', help = 'Specifies yaml-config file')
     parser.add_argument('-g', '--generate', help='Generates config_demo.yaml file',action='store_true')
     parser.add_argument('-d', '--download', help='Download specified policy. If wildcard \'*\' is used then policies are filtered or all downloaded.')
     parser.add_argument('-u', '--upload', help='Upload new policy (path). If path is directory all json-files uploaded. If path is a pattern like \'policies/mycompany.\' all matching json-files are uploaded.')
